SUDE documentation
==================

SUDE is a scalable manifold learning package for computing low-dimensional
embeddings from high-dimensional data.

.. toctree::
   :maxdepth: 2

   quick_start
   user_guide
   api
